# -*- coding: utf-8 -*-

from rest_framework import serializers

from ... import models
from thx.api.serializers import (
    ThuxListSerializerMixin, ThuxRetrieveSerializerMixin, ThuxCreateSerializerMixin,
    ThuxUpdateSerializerMixin, ThuxPartialUpdateSerializerMixin, ThuxStatusSerializerMixin,
    ThuxEnableSerializerMixin, ThuxDisableSerializerMixin
)


# OFFICE
class OfficeSerializer(serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_office_office'
        model = models.Office
        fields = '__all__'


class OfficeListSerializer(ThuxListSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_office_office_list'
        model = models.Office
        fields = '__all__'

    def get_field_names(self, *args, **kwargs):
        profile = self.context.get('view').kwargs['profile']
        fields = super().get_field_names(*args, **kwargs)
        if profile == '':
            return fields
        return []


class OfficeRetrieveSerializer(ThuxRetrieveSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_office_office_retrieve'
        model = models.Office
        fields = '__all__'

    def get_field_names(self, *args, **kwargs):
        profile = self.context.get('view').kwargs['profile']
        fields = super().get_field_names(*args, **kwargs)
        if profile == '':
            return fields
        return []


class OfficeCreateSerializer(ThuxCreateSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_office_office_create'
        model = models.Office
        exclude = ('date_create', 'date_last_modify', 'creator', 'last_modifier')

    def get_field_names(self, *args, **kwargs):
        profile = self.context.get('view').kwargs['profile']
        fields = super().get_field_names(*args, **kwargs)
        if profile == '':
            return fields
        return []

    def to_representation(self, instance):
        return OfficeListSerializer(instance, context=self.context).data


class OfficeUpdateSerializer(ThuxUpdateSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_office_office_update'
        model = models.Office
        exclude = ('date_create', 'date_last_modify', 'creator', 'last_modifier')

    def get_field_names(self, *args, **kwargs):
        profile = self.context.get('view').kwargs['profile']
        fields = super().get_field_names(*args, **kwargs)
        if profile == '':
            return fields
        return []

    def to_representation(self, instance):
        return OfficeRetrieveSerializer(instance, context=self.context).data


class OfficePartialUpdateSerializer(ThuxPartialUpdateSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_office_office_partial_update'
        model = models.Office
        exclude = ('date_create', 'date_last_modify', 'creator', 'last_modifier')

    def get_field_names(self, *args, **kwargs):
        profile = self.context.get('view').kwargs['profile']
        fields = super().get_field_names(*args, **kwargs)
        if profile == '':
            return fields
        return []

    def to_representation(self, instance):
        return OfficeRetrieveSerializer(instance, context=self.context).data


class OfficeEnableSerializer(ThuxEnableSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_office_office_enable'
        model = models.Office
        fields = ()

    def update(self, instance, validated_data):
        instance.status = 1
        instance.save()
        return instance

    def to_representation(self, instance):
        return OfficeRetrieveSerializer(instance, context=self.context).data


class OfficeDisableSerializer(ThuxDisableSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_office_office_disable'
        model = models.Office
        fields = ()

    def update(self, instance, validated_data):
        instance.status = 0
        instance.save()
        return instance

    def to_representation(self, instance):
        return OfficeRetrieveSerializer(instance, context=self.context).data


# AREA
class AreaSerializer(serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_office_area'
        model = models.Area
        fields = '__all__'


class AreaListSerializer(ThuxListSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_office_area_list'
        model = models.Area
        fields = '__all__'

    def get_field_names(self, *args, **kwargs):
        profile = self.context.get('view').kwargs['profile']
        fields = super().get_field_names(*args, **kwargs)
        if profile == '':
            return fields
        return []


class AreaRetrieveSerializer(ThuxRetrieveSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_office_area_retrieve'
        model = models.Area
        fields = '__all__'

    def get_field_names(self, *args, **kwargs):
        profile = self.context.get('view').kwargs['profile']
        fields = super().get_field_names(*args, **kwargs)
        if profile == '':
            return fields
        return []


class AreaCreateSerializer(ThuxCreateSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_office_area_create'
        model = models.Area
        exclude = ('date_create', 'date_last_modify', 'creator', 'last_modifier')

    def get_field_names(self, *args, **kwargs):
        profile = self.context.get('view').kwargs['profile']
        fields = super().get_field_names(*args, **kwargs)
        if profile == '':
            return fields
        return []

    def to_representation(self, instance):
        return AreaListSerializer(instance, context=self.context).data


class AreaUpdateSerializer(ThuxUpdateSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_office_area_update'
        model = models.Area
        exclude = ('date_create', 'date_last_modify', 'creator', 'last_modifier')

    def get_field_names(self, *args, **kwargs):
        profile = self.context.get('view').kwargs['profile']
        fields = super().get_field_names(*args, **kwargs)
        if profile == '':
            return fields
        return []

    def to_representation(self, instance):
        return AreaRetrieveSerializer(instance, context=self.context).data


class AreaPartialUpdateSerializer(ThuxPartialUpdateSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_office_area_partial_update'
        model = models.Area
        exclude = ('date_create', 'date_last_modify', 'creator', 'last_modifier')

    def get_field_names(self, *args, **kwargs):
        profile = self.context.get('view').kwargs['profile']
        fields = super().get_field_names(*args, **kwargs)
        if profile == '':
            return fields
        return []

    def to_representation(self, instance):
        return AreaRetrieveSerializer(instance, context=self.context).data


class AreaEnableSerializer(ThuxEnableSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_office_area_enable'
        model = models.Area
        fields = ()

    def update(self, instance, validated_data):
        instance.status = 1
        instance.save()
        return instance

    def to_representation(self, instance):
        return AreaRetrieveSerializer(instance, context=self.context).data


class AreaDisableSerializer(ThuxDisableSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_office_area_disable'
        model = models.Area
        fields = ()

    def update(self, instance, validated_data):
        instance.status = 0
        instance.save()
        return instance

    def to_representation(self, instance):
        return AreaRetrieveSerializer(instance, context=self.context).data
